<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="26"/>
        <source>Jump to today</source>
        <translation>Przejdź do dziś</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="27"/>
        <source>Jump to</source>
        <translation>Przejdź do daty</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <location filename="../AgendaPlug.cpp" line="122"/>
        <source>New event</source>
        <translation>Nowe zdarzenie</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="17"/>
        <source>Agenda</source>
        <translation>Plan</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="27"/>
        <source>Time in advance</source>
        <translation>Wyprzedzenie</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="37"/>
        <source>Hours</source>
        <translation>Godziny</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="57"/>
        <source>Minutes</source>
        <translation>Minuty</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="77"/>
        <source>Seconds</source>
        <translation>Sekundy</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="17"/>
        <source>Enable</source>
        <translation>Włączony</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="13"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="26"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="37"/>
        <source>Exact</source>
        <translation>Punktualny</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="39"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n godzina przed</numerusform>
            <numerusform>%n godziny przed</numerusform>
            <numerusform>%n godzin przed</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="40"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n minuta przed</numerusform>
            <numerusform>%n minuty przed</numerusform>
            <numerusform>%n minut przed</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="41"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n sekunda przed</numerusform>
            <numerusform>%n sekundyprzed</numerusform>
            <numerusform>%n sekund przed</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="43"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 przed</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="22"/>
        <source>From beginning</source>
        <translation>Od początku</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="23"/>
        <source>From end</source>
        <translation>Od końca</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="33"/>
        <source>By day of month</source>
        <translation>Według dnia miesiąca</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="35"/>
        <source>By week of year</source>
        <translation>Według tygodnia roku</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>By day of year</source>
        <translation>Według dnia roku</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="21"/>
        <source>By month</source>
        <translation>Według miesiąca</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="18"/>
        <source>By day of week</source>
        <translation>Według dnia tygodnia</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="36"/>
        <source>From beginning</source>
        <translation>Od początku</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="37"/>
        <source>From end</source>
        <translation>Od końca</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="6"/>
        <source>Edit calendar</source>
        <translation>Edytuj kalendarz</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="56"/>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="66"/>
        <source>Visible</source>
        <translation>Widoczny</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="26"/>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="27"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="131"/>
        <source>Save file</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="144"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Usunąc kalendarz i wszystkie jego zdarzenia, zadania i notatki?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Kalendarz</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Edytuj kalendarze</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="25"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n widoczny</numerusform>
            <numerusform>%n widoczne</numerusform>
            <numerusform>%n widocznych</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Cały
dzień</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="181"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="182"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="180"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Tydzień %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Wybierz datę</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Podaj numer dnia</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Poprzedni dzień</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Następny dzień</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Przejdź do dziś</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Przejdź do daty</translation>
    </message>
    <message>
        <location filename="../DayWindow.cpp" line="36"/>
        <source>New event</source>
        <translation>Nowe zdarzenie</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n zdarzenie</numerusform>
            <numerusform>%n zdarzenia</numerusform>
            <numerusform>%n zdarzeń</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n zadanie</numerusform>
            <numerusform>%n zadania</numerusform>
            <numerusform>%n zadań</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n notatka</numerusform>
            <numerusform>%n notatki</numerusform>
            <numerusform>%n notatek</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Miejsce</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Cały dzień</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Repeat</source>
        <translation>Powtarzaj</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="128"/>
        <source>Calendar</source>
        <translation>Kalendarz</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="69"/>
        <source>Edit event</source>
        <translation>Edytuj zdarzenie</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="87"/>
        <source>New event</source>
        <translation>Nowe zdarzenie</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Zdarzenie</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Powtarzanie</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="177"/>
        <source>Previous event</source>
        <translation>Poprzednie zdarzenie</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Next event</source>
        <translation>Następne zdarzenie</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Edit event</source>
        <translation>Edytuj zdarzenie</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Delete event</source>
        <translation>Usuń zdarzenie</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="133"/>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="133"/>
        <source>On</source>
        <translation>Dnia</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="203"/>
        <location filename="../EventWindow.cpp" line="224"/>
        <source>No more events</source>
        <translation>Nie ma więcej zdarzeń</translation>
    </message>
</context>
<context>
    <name>ExpandingTextEdit</name>
    <message>
        <location filename="../ExpandingTextEdit.cpp" line="101"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="17"/>
        <source>Calendar</source>
        <translation>Kalendarz</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>Edit note</source>
        <translation>Edytuj notatkę</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="32"/>
        <source>New note</source>
        <translation>Nowa notatka</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="27"/>
        <source>New note</source>
        <translation>Nowa notatka</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="46"/>
        <source>Notes</source>
        <translation>Notatki</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="120"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="121"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="56"/>
        <source>Month</source>
        <translation>Miesiąc</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="57"/>
        <source>Week</source>
        <translation>Tydzień</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="58"/>
        <source>Agenda</source>
        <translation>Plan</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="59"/>
        <source>Tasks</source>
        <translation>Zadania</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="60"/>
        <source>Notes</source>
        <translation>Notatki</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="61"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Previous month</source>
        <translation>Poprzedni miesiąc</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>Next month</source>
        <translation>Następny miesiąc</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="65"/>
        <source>Jump to today</source>
        <translation>Przejdź do dziś</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="66"/>
        <source>Jump to</source>
        <translation>Przejdź do daty</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="67"/>
        <source>New event</source>
        <translation>Nowe zdarzenie</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ChangeManager.cpp" line="47"/>
        <source>Unable to edit birthdays</source>
        <translation>Nie można edytować urodzin</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="57"/>
        <source>Delete component?</source>
        <translation>Usunąć obiekt?</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Powtarzanie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="28"/>
        <source>Repeat</source>
        <translation>Powtarzaj</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="50"/>
        <source>Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="61"/>
        <source>Daily</source>
        <translation>Dziennie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Weekly</source>
        <translation>Tygodniowo</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Monthly</source>
        <translation>Miesięcznie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Yearly</source>
        <translation>Rocznie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
        <source>Interval</source>
        <translation>Odstęp</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="108"/>
        <source>Forever</source>
        <translation>Wiecznie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Until</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Count</source>
        <translation>Powtórzenia</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="32"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="28"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="30"/>
        <source>External</source>
        <translation>Zewnętrzne</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="32"/>
        <source>Every day</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="34"/>
        <source>Every workday</source>
        <translation>W dni robocze</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="36"/>
        <source>Every week</source>
        <translation>Co tydzień</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="38"/>
        <source>Every month</source>
        <translation>Co miesiąc</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="40"/>
        <source>Every year</source>
        <translation>Co rok</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="42"/>
        <source>Complex</source>
        <translation>Złożone</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="32"/>
        <source>Edit calendars</source>
        <translation>Edytuj kalendarze</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="42"/>
        <source>Delete events</source>
        <translation>Usuń zdarzenia</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="52"/>
        <source>Delete tasks</source>
        <translation>Usuń zadania</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="14"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="43"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="45"/>
        <location filename="../settings/SettingsDialog.cpp" line="47"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Starsze niż %n tydzień</numerusform>
            <numerusform>Starsze niż %n tygodnie</numerusform>
            <numerusform>Starsze niż %n tygodni</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="49"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Starsze niż %n miesiąc</numerusform>
            <numerusform>Starsze niż %n miesiące</numerusform>
            <numerusform>Starsze niż %n miesięcy</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="51"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Starsze niż %n rok</numerusform>
            <numerusform>Starsze niż %n lata</numerusform>
            <numerusform>Starsze niż %n lat</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Calendar</source>
        <translation>Kalendarz</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <location filename="../TodoEditDialog.ui" line="61"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="44"/>
        <source>Edit task</source>
        <translation>Edytuj zadanie</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="61"/>
        <source>New task</source>
        <translation>Nowe zadanie</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Zadanie</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Termin</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="167"/>
        <source>Edit task</source>
        <translation>Edytuj zadanie</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="172"/>
        <source>Delete task</source>
        <translation>Usuń zadanie</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="33"/>
        <source>New task</source>
        <translation>Nowe zadanie</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="40"/>
        <source>Hide completed</source>
        <translation>Ukryj zakończone</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Delete completed</source>
        <translation>Usuń zakończone</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="78"/>
        <source>Tasks</source>
        <translation>Zadania</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="198"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="199"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="224"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Usunąć zakończone zadania ze wszystkich kalendarzy?</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="31"/>
        <source>w%1</source>
        <translation>t%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="42"/>
        <source>Previous week</source>
        <translation>Poprzedni tydzień</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Next week</source>
        <translation>Następny tydzień</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Jump to today</source>
        <translation>Przejdź do dziś</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to</source>
        <translation>Przejdź do daty</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>New event</source>
        <translation>Nowe zdarzenie</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="69"/>
        <source>Week %1 (%2)</source>
        <translation>Tydzień %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="357"/>
        <source>All day</source>
        <translation>Cały dzień</translation>
    </message>
</context>
</TS>
